<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru_UA">
<context>
    <name>QStarDict::CSSEdit</name>
    <message>
        <location filename="../cssedit.ui" line="16"/>
        <source>Preview</source>
        <translation type="unfinished">Попередній перегляд</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="30"/>
        <source>Element</source>
        <translation type="unfinished">Елемент</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="37"/>
        <source>Foreground</source>
        <translation type="unfinished">Передній план</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="44"/>
        <source>Background</source>
        <translation type="unfinished">Задній план</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="51"/>
        <source>Select element</source>
        <translation type="unfinished">Вибір елемента</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="68"/>
        <source>Click to select color</source>
        <translation type="unfinished">Клік для вибору кольору</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="71"/>
        <source>#000000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="78"/>
        <source>Font</source>
        <translation type="unfinished">Шрифт</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="85"/>
        <source>Size</source>
        <translation type="unfinished">Розмір</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="92"/>
        <source>Select font</source>
        <translation type="unfinished">Вибір шрифту</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="99"/>
        <source>Select font size</source>
        <translation type="unfinished">Вибір розміру шрифту</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="102"/>
        <source>pt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="127"/>
        <source>Bold</source>
        <translation type="unfinished">Жирний</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="130"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="147"/>
        <source>Italic</source>
        <translation type="unfinished">Курсив</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="150"/>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="167"/>
        <source>Underline</source>
        <translation type="unfinished">Підкреслений</translation>
    </message>
    <message>
        <location filename="../cssedit.ui" line="170"/>
        <source>U</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QStarDict::DictBrowser</name>
    <message>
        <location filename="../dictbrowser.cpp" line="72"/>
        <source>The word &lt;b&gt;%1&lt;/b&gt; is not found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QStarDict::DictWidget</name>
    <message>
        <location filename="../dictwidget.cpp" line="114"/>
        <source>Save translation</source>
        <translation type="unfinished">Зберегти переклад</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="135"/>
        <source>HTML files (*.html, *.htm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="124"/>
        <source>Text files (*.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="130"/>
        <source>Error</source>
        <translation type="unfinished">Помилка</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="131"/>
        <source>Cannot save translation as %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="75"/>
        <source>Go to &amp;previous translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="80"/>
        <source>Go to &amp;next translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="85"/>
        <source>&amp;Save to file</source>
        <translation type="unfinished">&amp;Зберегти в файл</translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="91"/>
        <source>Speak &amp;word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dictwidget.cpp" line="88"/>
        <source>Prin&amp;t translation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QStarDict::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="114"/>
        <source>About QStarDict</source>
        <translation type="unfinished">Про програму QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>&lt;b&gt;QStarDict %1 &lt;/b&gt; - Qt version of StarDict&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Copyright (C) 2007 Alexander Rodin &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</source>
        <translation type="unfinished">Copyright (C) 2007 Александр Родин &lt;a href=&quot;http://qstardict.ylsoftware.com&quot;&gt;http://qstardict.ylsoftware.com&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="13"/>
        <source>QStarDict</source>
        <translation type="unfinished">QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="183"/>
        <source>%1 - QStarDict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Clear the search box</source>
        <translation type="unfinished">Очистити рядок пошуку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Clear</source>
        <translation type="unfinished">Почистити</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Fuzzy query</source>
        <translation type="unfinished">Нечiткий запит</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Search</source>
        <translation type="unfinished">Пошук</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Words list</source>
        <translation type="unfinished">Список слiв</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Довiдка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Налаштування</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Вихiд</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished">Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;Про програму QStarDict</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Про &amp;бiблiотеку Qt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&amp;Configure QStarDict</source>
        <translation type="unfinished">&amp;Конфiгурацiя</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>&amp;Scan</source>
        <translation type="unfinished">&amp;Сканувати</translation>
    </message>
</context>
<context>
    <name>QStarDict::SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Enabled</source>
        <translation type="unfinished">Включено</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Name</source>
        <translation type="unfinished">Ім&apos;я</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="68"/>
        <source>Plugin</source>
        <translation type="unfinished">Плагін</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="261"/>
        <source>Information about dictionary &quot;%1&quot;</source>
        <translation type="unfinished">Інформація про словник &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="279"/>
        <source>&lt;b&gt;Name:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished">&lt;b&gt;Ім&apos;я:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="263"/>
        <source>&lt;b&gt;Plugin:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished">&lt;b&gt;Плагін:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="265"/>
        <source>unknown</source>
        <translation type="unfinished">невідомо</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="283"/>
        <source>&lt;b&gt;Description:&lt;/b&gt; %1</source>
        <translation type="unfinished">&lt;b&gt;Опис:&lt;/b&gt; %1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="278"/>
        <source>Information about %1 plugin</source>
        <translation type="unfinished">Інформація про %1 плагін</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="280"/>
        <source>&lt;b&gt;Version:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished">&lt;b&gt;Версія:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="281"/>
        <source>&lt;b&gt;Authors:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished">&lt;b&gt;Автори:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="281"/>
        <source>&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>&lt;b&gt;Can search similar words:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished">&lt;b&gt;Шукати подібні слова:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>yes</source>
        <translation type="unfinished">Так</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="282"/>
        <source>no</source>
        <translation type="unfinished">Ні</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>QStarDict Settings</source>
        <translation type="unfinished">Налаштування QStarDict</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="16"/>
        <source>Show information about dictionary</source>
        <translation type="unfinished">Показати інформацію про словник</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Global settings</source>
        <translation type="unfinished">Глобальні налаштування</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Instant search</source>
        <translation type="unfinished">Миттєвий пошук</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Pronounce words using this command:</source>
        <translation type="unfinished">Вимовляти слова, використовуючи цю команду: </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Enter cmd for the speaching program.&lt;br&gt;If cmd contains &quot;%s&quot; it will be replaced to word, else word will be writen to stdin of speech process.</source>
        <translation type="unfinished">Введіть команду для розмовної програми. &lt;br&gt;Якщо команда містить &quot;%s&quot; це буде замінено словом, інaкше слово буде записано на stdin.</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Dictionaries</source>
        <translation type="unfinished">Словники</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="147"/>
        <source>Move up</source>
        <translation type="unfinished">Перейти вверх</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="150"/>
        <source>Up</source>
        <translation type="unfinished">Уверх</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Move down</source>
        <translation type="unfinished">Перейти вниз</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>Down</source>
        <translation type="unfinished">Вниз</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>Show info</source>
        <translation type="unfinished">Показати інформацію</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="207"/>
        <source>Plugins</source>
        <translation type="unfinished">Плагіни</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <source>Show information about plugin</source>
        <translation type="unfinished">Показати інформацію про плагін</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="237"/>
        <source>Info</source>
        <translation type="unfinished">Інфо</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="247"/>
        <source>Configure plugin</source>
        <translation type="unfinished">Налаштувати плагін</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Configure</source>
        <translation type="unfinished">Конфігурація</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>Popup window</source>
        <translation type="unfinished">Вiкно повiдомлення</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="303"/>
        <source>Behavior</source>
        <translation type="unfinished">Поведiнка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="344"/>
        <source>Pronounce the word</source>
        <translation type="unfinished">Вимовити слово</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="370"/>
        <source>Timeout before hide after mouse over</source>
        <translation type="unfinished">Затримка приховування пiсля &quot;втечi&quot; мишi з вiкна переклада</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="377"/>
        <source>Don&apos;t hide</source>
        <translation type="unfinished">Не приховувати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source> sec</source>
        <translation type="unfinished">сек</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="424"/>
        <source>Show only if modifier pressed</source>
        <translation type="unfinished">Показувати тiльки якщо натиснута клавiша-модифiкатор</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="435"/>
        <source>Alt</source>
        <translation type="unfinished">Alt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="440"/>
        <source>Control</source>
        <translation type="unfinished">Control</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="445"/>
        <source>Shift</source>
        <translation type="unfinished">Shift</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="450"/>
        <source>Win</source>
        <translation type="unfinished">Win</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="460"/>
        <source>Scan selection</source>
        <translation type="unfinished">Сканувати видiлення</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="470"/>
        <source>Show if word not found</source>
        <translation type="unfinished">Показувати, якщо слово не знайдено</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="644"/>
        <source>Apperance</source>
        <translation type="unfinished">Зовнiшнiй вигляд</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="521"/>
        <source>Opacity</source>
        <translation type="unfinished">Непрозорiсть</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="528"/>
        <source>%</source>
        <translation type="unfinished">%</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="566"/>
        <source>Default width</source>
        <translation type="unfinished">Ширина за замовчуванням</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="605"/>
        <source>Default height</source>
        <translation type="unfinished">Висота за замовчуванням</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="264"/>
        <source>&lt;b&gt;Author:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished">&lt;b&gt;Автор:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="265"/>
        <source>&lt;b&gt;Words count:&lt;/b&gt; %1&lt;br&gt;</source>
        <translation type="unfinished">&lt;b&gt;Кількість слів:&lt;/b&gt; %1&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="113"/>
        <source>All translation</source>
        <translation type="unfinished">Всі переклади</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <source>Dictionary name</source>
        <translation type="unfinished">Ім&apos;я словника</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="115"/>
        <source>Title</source>
        <translation type="unfinished">Заголовок</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="116"/>
        <source>Explanation</source>
        <translation type="unfinished">Проголошення</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="117"/>
        <source>Abbreviation</source>
        <translation type="unfinished">Абревіатури</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <source>Example</source>
        <translation type="unfinished">Приклад</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="119"/>
        <source>Transcription</source>
        <translation type="unfinished">Транскрипція</translation>
    </message>
</context>
<context>
    <name>QStarDict::TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="36"/>
        <source>QStarDict</source>
        <translation type="unfinished">QStarDict</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="37"/>
        <source>&amp;Scan</source>
        <translation type="unfinished">&amp;Сканувати</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="47"/>
        <source>&amp;Configure QStarDict</source>
        <translation type="unfinished">&amp;Конфiгурацiя</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="50"/>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Вихiд</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>QStarDict: scanning is %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="84"/>
        <source>disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
